DROP SEQUENCE publishers_publisherID_SEQ;
DROP TABLE publishers;
CREATE TABLE publishers (
       publisherID SERIAL NOT NULL,
       PRIMARY KEY(publisherID),
       pb_name TEXT NOT NULL UNIQUE, 
       CONSTRAINT publishers_pb_name_check CHECK(character_length(pb_name) > 0)
);

DROP SEQUENCE magazines_magazineID_SEQ;
DROP TABLE magazines;
CREATE TABLE magazines (
       publisherID INTEGER NOT NULL,
       magazineID SERIAL NOT NULL,
       mag_name TEXT NOT NULL,
       list_price INTEGER NOT NULL,
       PRIMARY KEY(magazineID),
       UNIQUE(mag_name,publisherID),
       CONSTRAINT magazines_mag_name_check CHECK(character_length(mag_name) > 0),
       CONSTRAINT magazines_list_price_check CHECK(list_price > 0)
);

ALTER TABLE magazines ADD CONSTRAINT magazines_pb_name_fkey
      FOREIGN KEY(publisherID) REFERENCES publishers;

DROP SEQUENCE iss_mags_iss_magID_SEQ;
DROP TABLE iss_mags;
CREATE TABLE iss_mags (
       magazineID INTEGER NOT NULL,
       iss_magID SERIAL NOT NULL,
       issue_date DATE NOT NULL,
       price INTEGER NOT NULL,
       total_pages INTEGER NOT NULL,
       PRIMARY KEY(iss_magID),
       UNIQUE(magazineID,issue_date),
       CONSTRAINT iss_mags_price_check CHECK(price > 0),
       CONSTRAINT iss_mags_total_pages_check CHECK(total_pages > 0)
);

ALTER TABLE iss_mags ADD CONSTRAINT iss_mags_magazine_fkey
      FOREIGN KEY(magazineID) REFERENCES magazines;

DROP SEQUENCE articles_articleID_SEQ;
DROP TABLE articles;
CREATE TABLE articles (
       iss_magID INTEGER NOT NULL,
       articleID SERIAL NOT NULL,
       title TEXT NOT NULL,
       start_page INTEGER NOT NULL,
       num_pages INTEGER NOT NULL,
       PRIMARY KEY(articleID),
       UNIQUE(title,iss_magID),
       CONSTRAINT articles_title_check CHECK(character_length(title) > 0),
       CONSTRAINT articles_start_page_check CHECK(start_page > 0),
       CONSTRAINT articles_num_pages_check CHECK(num_pages > 0)
);

ALTER TABLE articles ADD CONSTRAINT articles_iss_mags_fkey
      FOREIGN KEY(iss_magID) REFERENCES iss_mags;

DROP SEQUENCE writers_writerID_SEQ;
DROP TABLE writers;
CREATE TABLE writers (
       writerID SERIAL NOT NULL,
       wrt_name TEXT NOT NULL,
       email TEXT UNIQUE,
       ph_number TEXT UNIQUE,
       PRIMARY KEY(writerID),
       CONSTRAINT writers_wrt_name_check CHECK(character_length(wrt_name) > 0)
);

CREATE INDEX writers_wrt_name_idx ON writers(wrt_name);

DROP TABLE writings;
CREATE TABLE writings (
       articleID INTEGER NOT NULL,
       writerID INTEGER NOT NULL,
       PRIMARY KEY(articleID,writerID)
);

ALTER TABLE writings ADD CONSTRAINT writings_article_fkey
      FOREIGN KEY(articleID) REFERENCES articles;
ALTER TABLE writings ADD CONSTRAINT writings_writer_fkey
      FOREIGN KEY(writerID) REFERENCES writers;

DROP SEQUENCE keywords_keywordID_SEQ;
DROP TABLE keywords;
CREATE TABLE keywords (
       keywordID SERIAL NOT NULL,
       keyword TEXT NOT NULL,
       english_keyword TEXT NOT NULL,
       PRIMARY KEY(keywordID),
       UNIQUE(keyword,english_keyword),
       CONSTRAINT keywords_keyword_check CHECK(character_length (keyword) > 0),
       CONSTRAINT keywords_english_keyword_check CHECK(character_length(english_keyword) > 0)
);

DROP TABLE articles_keywords;
CREATE TABLE articles_keywords (
       articleID INTEGER NOT NULL,
       keywordID INTEGER NOT NULL,
       PRIMARY KEY(articleID,keywordID)
);

ALTER TABLE articles_keywords ADD CONSTRAINT articles_keywords_article_fkey
      FOREIGN KEY(articleID) REFERENCES articles;
ALTER TABLE articles_keywords ADD CONSTRAINT articles_keywords_keyword_fkey
      FOREIGN KEY(keywordID) REFERENCES keywords;
